@@ -57,6 +57,7 @@ class DataArray(ArrayBase):
 class IntegerArray(DataArray):
 
     associated_genres = ("charge", "multiplicity")
+    full_name_ref = {"charge": "Charge", "multiplicity": "Multiplicity"}
     values = ArrayProperty(dtype=int, check_against="filenames")
 
 
@@ -84,7 +85,11 @@ class FloatArray(DataArray):
 
 
 class InfoArray(DataArray):
-    full_name_ref = {}
+    full_name_ref = {
+        "command": "Command",
+        "cpu_time": "CPU Time",
+        "stoichiometry": "Stoichiometry",
+    }
     _units = {}
     associated_genres = (
         "command",
@@ -296,9 +301,9 @@ class Bands(FloatArray):
     full_name_ref = {
         "ex_en": "Excitation energy",
         "freq": "Frequency",
-        "wave": "Wavelength",
+        "wavelen": "Wavelength",
     }
-    _units = {"freq": "cm^(-1)", "wave": "nm", "ex_en": "eV"}
+    _units = {"freq": "cm^(-1)", "wavelen": "nm", "ex_en": "eV"}
 
     def __init__(
         self,
@@ -385,6 +390,11 @@ class SpectralData(FloatArray, ABC):
 
     associated_genres = ()
 
+    @property
+    @abstractmethod
+    def spectra_type(self):
+        return NotImplemented
+
     @property
     @abstractmethod
     def freq(self):
@@ -431,6 +441,10 @@ class VibrationalData(_VibData):
     )
     _units = dict(mass="AMU", frc="mDyne/A", emang="deg")
 
+    @property
+    def spectra_type(self):
+        return "vibrational"
+
 
 class ScatteringData(_VibData):
     associated_genres = (
@@ -471,6 +485,10 @@ class ScatteringData(_VibData):
         "delta2": "(10**4 A**5/AMU)",
     }
 
+    @property
+    def spectra_type(self):
+        return "scattering"
+
     def __init__(
         self,
         genre,
@@ -492,6 +510,10 @@ class ElectronicData(SpectralData):
     full_name_ref = dict(eemang="E-M Angle")
     _units = dict(eemang="deg")
 
+    @property
+    def spectra_type(self):
+        return "electronic"
+
     def __init__(
         self,
         genre,
@@ -530,14 +552,6 @@ class SpectralActivities(SpectralData, Averagable, ABC):
         vdip="uv",
         ldip="uv",
     )
-    spectra_type_ref = dict(
-        vcd="vibrational",
-        ir="vibrational",
-        roa="scattering",
-        raman="scattering",
-        ecd="electronic",
-        uv="electronic",
-    )
     full_name_ref = dict()
     _units = dict()
     _intensities_converters = {}
@@ -547,11 +561,6 @@ class SpectralActivities(SpectralData, Averagable, ABC):
         if self.genre in self.spectra_name_ref:
             return self.spectra_name_ref[self.genre]
 
-    @property
-    def spectra_type(self):
-        if self.genre in self.spectra_name_ref:
-            return self.spectra_type_ref[self.spectra_name]
-
     @property
     def intensities(self):
         """Converts spectral activity calculated by quantum chemistry software
@@ -661,6 +670,7 @@ class VibrationalActivities(VibrationalData, _VibAct):
 
 class ScatteringActivities(ScatteringData, _VibAct):
     associated_genres = (
+        "ramanactiv",
         "ramact",
         "raman1",
         "roa1",
@@ -670,6 +680,7 @@ class ScatteringActivities(ScatteringData, _VibAct):
         "roa3",
     )
     full_name_ref = dict(
+        ramanactiv="Raman scatt. activities",
         ramact="Raman scatt. activities",
         roa1="ROA inten. ICPu/SCPu(180)",
         raman1="Raman inten. ICPu/SCPu(180)",
@@ -679,6 +690,7 @@ class ScatteringActivities(ScatteringData, _VibAct):
         raman3="Raman inten. DCPI(180)",
     )
     _units = dict(
+        ramanactiv="A^4/AMU",
         ramact="A^4/AMU",
         roa1="10^4 K",
         raman1="K",
@@ -688,6 +700,7 @@ class ScatteringActivities(ScatteringData, _VibAct):
         raman3="K",
     )
     _intensities_converters = {
+        "ramanactiv": _as_is,
         "ramact": _as_is,
         "raman1": _as_is,
         "roa1": _as_is,
@@ -972,7 +985,7 @@ class Geometry(FloatArray):
     """
 
     associated_genres = ("geometry", "input_geom")
-    full_name_ref = dict(geometry="Geometry")
+    full_name_ref = dict(geometry="Geometry", input_geom="Input Geometry")
     _units = dict(geometry="Angstrom")
     values = ArrayProperty(dtype=float, check_against="filenames")
     molecule_atoms = CollapsibleArrayProperty(
