@@ -74,13 +74,27 @@ class Writer(ABC):
     """
 
     _header = dict(
-        # TODO: add missing headers
+        zpecorr="Zero-point Corr.",
+        tencorr="Thermal Corr.",
+        stoichiometry="Stoichiometry",
+        entcorr="Enthalpy Corr.",
+        geometry="Geometry",
+        optimization_completed="Optimized",
+        input_geom="Input Geom.",
+        command="Command",
+        multiplicity="Multiplicity",
+        transitions="Transitions",
+        cpu_time="CPU Time",
+        gibcorr="Gibbs Corr.",
+        charge="Charge",
+        normal_termination="Termination",
+        filenames="Filename",
         freq="Frequencies",
         mass="Red. masses",
         frc="Frc consts",
-        raman="Raman Activ",
-        depolarp=r"Depolar (P)",
-        depolaru=r"Depolar (U)",
+        ramanactiv="Raman Activ",
+        depolarp="Depolar (P)",
+        depolaru="Depolar (U)",
         ramact="RamAct",
         depp="Dep-P",
         depu="Dep-U",
@@ -126,6 +140,21 @@ class Writer(ABC):
         ecd="{:> .4e}",
         raman="{:> .4e}",
         roa="{:> .4e}",
+        zpecorr="{:> 10.4f}",
+        tencorr="{:> 10.4f}",
+        entcorr="{:> 10.4f}",
+        gibcorr="{:> 10.4f}",
+        stoichiometry="{}",
+        geometry="{}",
+        optimization_completed="{}",
+        input_geom="{}",
+        command="{}",
+        multiplicity="{:^ 12d}",
+        charge="{:^ 6d}",
+        transitions="{}",
+        cpu_time="{}",
+        normal_termination="{}",
+        filenames="{}",
         rot="{:> 10.4f}",
         dip="{:> 10.4f}",
         roa1="{:> 10.4f}",
@@ -151,6 +180,7 @@ class Writer(ABC):
         frc="{:> 10.4f}",
         depolarp="{:> 11.4f}",
         depolaru="{:> 11.4f}",
+        ramanactiv="{:> 10.4f}",
         ramact="{:> 10.4f}",
         depp="{:> 9.4f}",
         depu="{:> 9.4f}",
@@ -170,10 +200,25 @@ class Writer(ABC):
     )
 
     _excel_formats = dict(
+        zpecorr="0.0000",
+        tencorr="0.0000",
+        entcorr="0.0000",
+        gibcorr="0.0000",
+        multiplicity="{0",
+        charge="0",
+        stoichiometry="",
+        geometry="",
+        optimization_completed="",
+        input_geom="",
+        command="",
+        transitions="",
+        cpu_time="",
+        normal_termination="",
+        filenames="",
         freq="0.0000",
         mass="0.0000",
         frc="0.0000",
-        raman="0.0000",
+        ramanactiv="0.0000",
         depolarp="0.0000",
         depolaru="0.0000",
         ramact="0.0000",
