@@ -8,7 +8,6 @@ from typing import Iterable, Optional, Sequence, Union
 import numpy as np
 import openpyxl as oxl
 
-from ._writer import Writer
 from ..glassware.arrays import (
     Bands,
     DataArray,
@@ -20,6 +19,7 @@ from ..glassware.arrays import (
     Transitions,
 )
 from ..glassware.spectra import SingleSpectrum, Spectra
+from ._writer import Writer
 
 # LOGGER
 logger = lgg.getLogger(__name__)
@@ -214,7 +214,7 @@ class XlsxWriter(Writer):
         self,
         band: SpectralActivities,
         data: Iterable[SpectralData],
-        name_template: Union[str, Template] = "${conf}.${cat}-${genre}",
+        name_template: Union[str, Template] = "${conf}.${cat}-${det}",
     ):
         """Writes SpectralData objects to xlsx file (one sheet for each conformer).
 
@@ -226,10 +226,16 @@ class XlsxWriter(Writer):
             excitation energies for electronic data
         data: iterable of glassware.SpectralData
             SpectralData objects that are to be serialized; all should contain
-            information for the same conformers.
+            information for the same conformers. Assumes that all `data`'s elements have
+            the same `spectra_type`, which is passed to the `name_template` as "det".
         name_template : str or string.Template
             Template that will be used to generate filenames,
-            defaults to "${conf}.${cat}-${genre}".
+            defaults to "${conf}.${cat}-${det}".
+
+        Raises
+        ------
+        ValueError
+            if `data` is an empty sequence
         """
         self._spectral(
             band=band, data=data, name_template=name_template, category="data"
@@ -239,7 +245,7 @@ class XlsxWriter(Writer):
         self,
         band: SpectralActivities,
         data: Iterable[SpectralActivities],
-        name_template: Union[str, Template] = "${conf}.${cat}-${genre}",
+        name_template: Union[str, Template] = "${conf}.${cat}-${det}",
     ):
         """Writes SpectralActivities objects to xlsx file (one sheet for each conformer).
 
@@ -251,10 +257,16 @@ class XlsxWriter(Writer):
             excitation energies for electronic data
         data: iterable of glassware.SpectralActivities
             SpectralActivities objects that are to be serialized; all should contain
-            information for the same conformers.
+            information for the same conformers. Assumes that all `data`'s elements have
+            the same `spectra_type`, which is passed to the `name_template` as "det".
         name_template : str or string.Template
             Template that will be used to generate filenames,
-            defaults to "${conf}.${cat}-${genre}".
+            defaults to "${conf}.${cat}-${det}".
+
+        Raises
+        ------
+        ValueError
+            if `data` is an empty sequence
         """
         self._spectral(
             band=band, data=data, name_template=name_template, category="activities"
@@ -276,21 +288,32 @@ class XlsxWriter(Writer):
             it should be frequencies for vibrational data and wavelengths or
             excitation energies for electronic data
         data: iterable of glassware.SpectralActivities or iterable of SpectralData
-            SpectralActivities or SpectralData objects that are to be serialized;
-            all should contain information for the same conformers.
+            SpectralActivities or SpectralData objects that are to be serialized; all
+            should contain information for the same conformers. Assumes that all
+            `data`'s elements have the same `spectra_type`, which is passed to the
+            `name_template` as "det".
         name_template : str or string.Template
             Template that will be used to generate filenames.
         category : str
             Category of exported data genres.
+
+        Raises
+        ------
+        ValueError
+            if `data` is an empty sequence
         """
         wb = self.workbook
         data = [band] + list(data)
+        try:
+            spectra_type = data[1].spectra_type
+        except IndexError:
+            raise ValueError("No data to export.")
         genres = [bar.genre for bar in data]
         headers = [self._header[genre] for genre in genres]
         widths = [max(len(h), 10) for h in headers]
         fmts = [self._excel_formats[genre] for genre in genres]
         values = list(zip(*[bar.values for bar in data]))
-        template_params = {"genre": band.genre, "cat": category}
+        template_params = {"genre": band.genre, "cat": category, "det": spectra_type}
         for num, (fname, values_) in enumerate(zip(data[0].filenames, values)):
             template_params.update({"conf": fname, "num": num})
             ws = wb.create_sheet(title=self.make_name(name_template, **template_params))
